@@ -165,7 +165,10 @@ register_element_cls('c:numFmt',           CT_NumFmt)
 register_element_cls('c:order',            CT_UnsignedInt)
 register_element_cls('c:overlay',          CT_Boolean_Explicit)
 register_element_cls('c:ptCount',          CT_UnsignedInt)
+register_element_cls('c:showCatName',      CT_Boolean_Explicit)
 register_element_cls('c:showLegendKey',    CT_Boolean_Explicit)
+register_element_cls('c:showPercent',      CT_Boolean_Explicit)
+register_element_cls('c:showSerName',      CT_Boolean_Explicit)
 register_element_cls('c:showVal',          CT_Boolean_Explicit)
 register_element_cls('c:smooth',           CT_Boolean)
 register_element_cls('c:title',            CT_Title)
@@ -306,19 +309,6 @@ register_element_cls('p:spPr',  CT_ShapeProperties)
 register_element_cls('p:xfrm',  CT_Transform2D)
 
 
-from .shapes.table import (  # noqa: E402
-    CT_Table, CT_TableCell, CT_TableCellProperties, CT_TableCol,
-    CT_TableGrid, CT_TableProperties, CT_TableRow
-)
-register_element_cls('a:gridCol', CT_TableCol)
-register_element_cls('a:tbl',     CT_Table)
-register_element_cls('a:tblGrid', CT_TableGrid)
-register_element_cls('a:tblPr',   CT_TableProperties)
-register_element_cls('a:tc',      CT_TableCell)
-register_element_cls('a:tcPr',    CT_TableCellProperties)
-register_element_cls('a:tr',      CT_TableRow)
-
-
 from .slide import (  # noqa: E402
     CT_Background, CT_BackgroundProperties, CT_CommonSlideData,
     CT_NotesMaster, CT_NotesSlide, CT_Slide, CT_SlideLayout,
@@ -340,6 +330,19 @@ register_element_cls('p:timing',         CT_SlideTiming)
 register_element_cls('p:video',          CT_TLMediaNodeVideo)
 
 
+from .table import (  # noqa: E402
+    CT_Table, CT_TableCell, CT_TableCellProperties, CT_TableCol,
+    CT_TableGrid, CT_TableProperties, CT_TableRow
+)
+register_element_cls('a:gridCol', CT_TableCol)
+register_element_cls('a:tbl',     CT_Table)
+register_element_cls('a:tblGrid', CT_TableGrid)
+register_element_cls('a:tblPr',   CT_TableProperties)
+register_element_cls('a:tc',      CT_TableCell)
+register_element_cls('a:tcPr',    CT_TableCellProperties)
+register_element_cls('a:tr',      CT_TableRow)
+
+
 from .text import (  # noqa: E402
     CT_RegularTextRun, CT_TextBody, CT_TextBodyProperties,
     CT_TextCharacterProperties, CT_TextField, CT_TextFont, CT_TextLineBreak,
